from tkinter import *
import os
from tkinter import messagebox
import sqlite3

def upload():
    current_dir = os.path.dirname(os.path.abspath(__file__))
    db_path = os.path.join(current_dir, "myDB.db")
    
    if not os.path.exists(db_path):
        messagebox.showerror("Error", "Database not found! Please run transfer_to_db.py first.")
        return []
        
    try:
        con = sqlite3.connect(db_path)
        cur = con.cursor()
        
        # Kiểm tra bảng staff có tồn tại không
        cur.execute("SELECT name FROM sqlite_master WHERE type='table' AND name='staff'")
        if not cur.fetchone():
            messagebox.showerror("Error", "Table 'staff' not found! Please run transfer_to_db.py first.")
            con.close()
            return []
            
        cur.execute("SELECT * FROM staff ORDER BY name")
        lst = cur.fetchall()
        con.close()
        return list(lst)
    except sqlite3.Error as e:
        messagebox.showerror("Error", f"Database error: {str(e)}")
        return []

def add_to_db(name, position, room, email):
    """Thêm staff mới vào database"""
    current_dir = os.path.dirname(os.path.abspath(__file__))
    db_path = os.path.join(current_dir, "myDB.db")
    
    try:
        con = sqlite3.connect(db_path)
        cur = con.cursor()
        cur.execute("INSERT INTO staff VALUES (?, ?, ?, ?)", 
                   (name, position, room, email))
        con.commit()
        con.close()
        return True
    except sqlite3.Error as e:
        messagebox.showerror("Error", f"Failed to add to database: {str(e)}")
        return False

def remove_from_db(name):
    """Xóa staff từ database"""
    current_dir = os.path.dirname(os.path.abspath(__file__))
    db_path = os.path.join(current_dir, "myDB.db")
    
    try:
        con = sqlite3.connect(db_path)
        cur = con.cursor()
        cur.execute("DELETE FROM staff WHERE name=?", (name,))
        con.commit()
        con.close()
        return True
    except sqlite3.Error as e:
        messagebox.showerror("Error", f"Failed to remove from database: {str(e)}")
        return False

window = Tk()
window.title("Staff")

# Main window widgets
lstName = Listbox(window, width=15, height=10)
yscroll = Scrollbar(command=lstName.yview)
lstName.grid(row=0, column=0, columnspan=2, padx=5, pady=5)
yscroll.grid(row=0, column=2, sticky=NS)
lstName.config(yscrollcommand=yscroll.set)

txt = Text(window, width=30, height=10)
txt.grid(row=0, column=3, padx=5, pady=5)

# Load staff list from database
staff_list = upload()
for staff in staff_list:
    lstName.insert(END, staff[0])

def show_add_window():
    add_window = Toplevel(window)
    add_window.title("Add New Staff")
    
    form_frame = Frame(add_window, padx=20, pady=10)
    form_frame.pack()
    
    name_var = StringVar()
    position_var = StringVar()
    room_var = StringVar()
    email_var = StringVar()
    
    Label(form_frame, text="Name:").grid(row=0, column=0, sticky=W, pady=5)
    name_entry = Entry(form_frame, textvariable=name_var)
    name_entry.grid(row=0, column=1, pady=5)
    
    Label(form_frame, text="Position:").grid(row=1, column=0, sticky=W, pady=5)
    position_entry = Entry(form_frame, textvariable=position_var)
    position_entry.grid(row=1, column=1, pady=5)
    
    Label(form_frame, text="Room:").grid(row=2, column=0, sticky=W, pady=5)
    room_entry = Entry(form_frame, textvariable=room_var)
    room_entry.grid(row=2, column=1, pady=5)
    
    Label(form_frame, text="Email:").grid(row=3, column=0, sticky=W, pady=5)
    email_entry = Entry(form_frame, textvariable=email_var)
    email_entry.grid(row=3, column=1, pady=5)
    
    def add_staff():
        name = name_var.get()
        position = position_var.get()
        room = room_var.get()
        email = email_var.get()
        
        if name and position and room and email:
            # Kiểm tra tên đã tồn tại
            if any(staff[0] == name for staff in staff_list):
                messagebox.showerror("Error", "Staff member already exists!")
                return
                
            # Thêm vào database
            if add_to_db(name, position, room, email):
                # Nếu thêm vào database thành công, cập nhật GUI
                new_staff = [name, position, room, email]
                staff_list.append(new_staff)
                lstName.insert(END, name)
                add_window.destroy()
                messagebox.showinfo("Success", "Staff member added successfully!")
        else:
            messagebox.showerror("Error", "Please fill all fields!")
    
    Button(form_frame, text="Add Staff", command=add_staff).grid(row=4, column=0, columnspan=2, pady=10)

def remove_staff():
    if not lstName.curselection():
        messagebox.showerror("Error", "Please select a staff member to remove!")
        return
        
    if messagebox.askyesno("Confirm", "Are you sure you want to remove this staff member?"):
        idx = lstName.curselection()[0]
        staff = staff_list[idx]
        
        # Xóa từ database
        if remove_from_db(staff[0]):
            # Nếu xóa từ database thành công, cập nhật GUI
            del staff_list[idx]
            lstName.delete(idx)
            txt.delete(1.0, END)
            messagebox.showinfo("Success", "Staff member removed successfully!")

def show_details(evt):
    if not lstName.curselection():
        return
        
    idx = lstName.curselection()[0]
    staff = staff_list[idx]
    
    txt.delete(1.0, END)
    for info in staff:
        txt.insert(END, str(info) + '\n')

button_frame = Frame(window)
button_frame.grid(row=1, column=3, pady=5)

Button(button_frame, text="Add", command=show_add_window).pack(side=LEFT, padx=5)
Button(button_frame, text="Remove", command=remove_staff).pack(side=LEFT, padx=5)

# Bind selection event
lstName.bind('<<ListboxSelect>>', show_details)

window.mainloop()