import tkinter as tk
from tkinter import ttk
from tkinter.messagebox import showinfo, showerror
import os
import sqlite3

class UserAccount:
    def __init__(self, username, password, position="", room="", email=""):
        self.__username = username
        self.__password = password
        self.__position = position
        self.__room = room
        self.__email = email
    
    def get_username(self):
        return self.__username
    
    def get_password(self):
        return self.__password
    
    def get_email(self):
        return self.__email

class LoginApp(tk.Tk):
    def __init__(self):
        super().__init__()
        
        self.title('Login System')
        self.geometry('300x150')
        self.resizable(0, 0)
        
        # Configure grid
        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=3)
        
        # Đường dẫn database
        current_dir = os.path.dirname(os.path.abspath(__file__))
        self.db_path = os.path.join(current_dir, "myDB.db")
        
        # Load users from database
        self.load_users()
        
        # Create widgets
        self.create_widgets()
    
    def load_users(self):
        self.users = []
        try:
            con = sqlite3.connect(self.db_path)
            cur = con.cursor()
            cur.execute("SELECT * FROM users")
            rows = cur.fetchall()
            for row in rows:
                user = UserAccount(row[0], row[1], row[2], row[3], row[4])
                self.users.append(user)
            con.close()
        except sqlite3.Error as e:
            showerror("Error", f"Database error: {str(e)}")
            self.users = []
    
    def add_user_to_db(self, username, password, position, room, email):
        """Add new user to database"""
        try:
            con = sqlite3.connect(self.db_path)
            cur = con.cursor()
            cur.execute("INSERT INTO users VALUES (?, ?, ?, ?, ?)",
                       (username, password, position, room, email))
            con.commit()
            con.close()
            return True
        except sqlite3.IntegrityError:
            showerror("Error", "Username or email already exists!")
            return False
        except sqlite3.Error as e:
            showerror("Error", f"Database error: {str(e)}")
            return False
    
    def create_widgets(self):
        # Username
        username_label = ttk.Label(self, text="Username:")
        username_label.grid(column=0, row=0, padx=5, pady=5)
        
        self.username_var = tk.StringVar()
        username_entry = ttk.Entry(self, textvariable=self.username_var)
        username_entry.grid(column=1, row=0, sticky=tk.EW, padx=5, pady=5)
        username_entry.bind('<Return>', lambda e: self.password_entry.focus())
        
        # Password
        password_label = ttk.Label(self, text="Password:")
        password_label.grid(column=0, row=1, padx=5, pady=5)
        
        self.password_var = tk.StringVar()
        self.password_entry = ttk.Entry(self, textvariable=self.password_var, show="*")
        self.password_entry.grid(column=1, row=1, sticky=tk.EW, padx=5, pady=5)
        self.password_entry.bind('<Return>', lambda e: self.login())
        
        # Button Frame
        button_frame = ttk.Frame(self)
        button_frame.grid(column=0, row=3, columnspan=2, pady=10)
        
        # Login button
        login_button = ttk.Button(button_frame, text="Login", command=self.login)
        login_button.pack(side=tk.LEFT, padx=5)
        
        # Register button
        register_button = ttk.Button(button_frame, text="Register", command=self.show_register)
        register_button.pack(side=tk.LEFT, padx=5)
    
    def login(self):
        username = self.username_var.get()
        password = self.password_var.get()
        
        try:
            con = sqlite3.connect(self.db_path)
            cur = con.cursor()
            
            # Kiểm tra username tồn tại
            cur.execute("SELECT * FROM users WHERE username=?", (username,))
            user = cur.fetchone()
            
            if user is None:
                showerror("Error", "Account not found!\nPlease register by clicking the Register button.")
            elif user[1] != password:
                showerror("Error", "Invalid password!")
            else:
                showinfo("Success", f"Welcome {username}!")
            
            con.close()
        except sqlite3.Error as e:
            showerror("Error", f"Database error: {str(e)}")
    
    def show_register(self):
        register_window = tk.Toplevel(self)
        register_window.title("Register New User")
        register_window.geometry("500x250")
        register_window.resizable(0, 0)

        # Configure the grid
        for i in range(6):
            register_window.rowconfigure(i, weight=1)
        register_window.columnconfigure(0, weight=1)
        register_window.columnconfigure(1, weight=0)
        register_window.columnconfigure(2, weight=2)
        register_window.columnconfigure(3, weight=1)

        # Username
        ttk.Label(register_window, text="Username:").grid(row=0, column=0, padx=5, pady=5, sticky='e')
        username_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=username_var).grid(row=0, column=2, padx=5, pady=5, sticky="ew")

        # Password
        ttk.Label(register_window, text="Password:").grid(row=1, column=0, padx=5, pady=5, sticky='e')
        password_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=password_var, show="*").grid(row=1, column=2, padx=5, pady=5, sticky="ew")

        # Position
        ttk.Label(register_window, text="Position:").grid(row=2, column=0, padx=5, pady=5, sticky='e')
        position_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=position_var).grid(row=2, column=2, padx=5, pady=5, sticky="ew")

        # Room
        ttk.Label(register_window, text="Room:").grid(row=3, column=0, padx=5, pady=5, sticky='e')
        room_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=room_var).grid(row=3, column=2, padx=5, pady=5, sticky="ew")

        # Email
        ttk.Label(register_window, text="Email:").grid(row=4, column=0, padx=5, pady=5, sticky='e')
        email_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=email_var).grid(row=4, column=2, padx=5, pady=5, sticky="ew")

        def register():
            username = username_var.get()
            password = password_var.get()
            position = position_var.get()
            room = room_var.get()
            email = email_var.get()

            if username and password and position and room and email:
                if self.add_user_to_db(username, password, position, room, email):
                    # Nếu thêm vào database thành công
                    new_user = UserAccount(username, password, position, room, email)
                    self.users.append(new_user)
                    showinfo("Success", "Registration successful!")
                    register_window.destroy()
            else:
                showerror("Error", "Please fill all fields!")

        def cancel():
            register_window.destroy()

        # Button Frame
        button_frame = ttk.Frame(register_window)
        button_frame.grid(row=5, column=1, columnspan=2, pady=15, sticky="ew")
        
        # Centering buttons
        button_frame.columnconfigure(0, weight=1)
        button_frame.columnconfigure(1, weight=1)

        # OK button
        ttk.Button(button_frame, text="OK", command=register).grid(row=0, column=0, padx=10)
        
        # Cancel button
        ttk.Button(button_frame, text="Cancel", command=cancel).grid(row=0, column=1, padx=10)

if __name__ == "__main__":
    app = LoginApp()
    app.mainloop()