import unittest
from my_sum import Calculate

class TestCalculate(unittest.TestCase):
    def setUp(self):
        self.calc = Calculate()  # Create instance
    
    # 5 Correct Expected Values
    def test_sum_positive(self):
        """Test sum with two positive numbers"""
        self.assertEqual(self.calc.sum(3, 4), 7)
    
    def test_sum_negative(self):
        """Test sum with two negative numbers"""
        self.assertEqual(self.calc.sum(-2, -3), -5)
    
    def test_sum_mixed(self):
        """Test sum with positive and negative numbers"""
        self.assertEqual(self.calc.sum(5, -2), 3)
    
    def test_multiply_positive(self):
        """Test multiply with two positive numbers"""
        self.assertEqual(self.calc.multiply(2, 3), 6)
    
    def test_multiply_negative(self):
        """Test multiply with positive and negative numbers"""
        self.assertEqual(self.calc.multiply(4, -2), -8)
    
    # 5 Incorrect Expected Values
    def test_sum_wrong_positive(self):
        """Test sum with incorrect positive result"""
        self.assertEqual(self.calc.sum(3, 4), 8)  # Should be 7
    
    def test_sum_wrong_negative(self):
        """Test sum with incorrect negative result"""
        self.assertEqual(self.calc.sum(-2, -3), -4)  # Should be -5
    
    def test_sum_wrong_zero(self):
        """Test sum with incorrect zero result"""
        self.assertEqual(self.calc.sum(5, -5), 1)  # Should be 0
    
    def test_multiply_wrong_positive(self):
        """Test multiply with incorrect positive result"""
        self.assertEqual(self.calc.multiply(2, 3), 5)  # Should be 6
    
    def test_multiply_wrong_negative(self):
        """Test multiply with incorrect negative result"""
        self.assertEqual(self.calc.multiply(4, -2), -7)  # Should be -8

    # Tests for subtract()
    def test_subtract_positive_integers(self):
        """Test subtract with positive integers"""
        self.assertEqual(self.calc.subtract(5, 3), 2)

    def test_subtract_negative_integers(self):
        """Test subtract with negative integers"""
        self.assertEqual(self.calc.subtract(-5, -2), -3)

    def test_subtract_mixed(self):
        """Test subtract with positive and negative integers"""
        self.assertEqual(self.calc.subtract(5, -2), 7)

    def test_subtract_floats(self):
        """Test subtract with floating-point numbers"""
        self.assertEqual(self.calc.subtract(3.5, 1.5), 2.0)

    def test_subtract_wrong(self):
        """Test subtract with incorrect result"""
        self.assertEqual(self.calc.subtract(5, 3), 3) # Should be 2

    # Tests for divide()
    def test_divide_positive_integers(self):
        """Test divide with positive integers"""
        self.assertEqual(self.calc.divide(6, 2), 3)

    def test_divide_negative_integers(self):
        """Test divide with negative integers"""
        self.assertEqual(self.calc.divide(-6, -2), 3)

    def test_divide_mixed(self):
        """Test divide with positive and negative integers"""
        self.assertEqual(self.calc.divide(8, -2), -4)

    def test_divide_floats(self):
        """Test divide with floating-point numbers"""
        self.assertEqual(self.calc.divide(4.5, 1.5), 3.0)

    def test_divide_by_zero(self):
        """Test divide by zero raises ValueError"""
        with self.assertRaises(ValueError):
            self.calc.divide(5, 0)

    def test_divide_wrong(self):
        """Test divide with incorrect result"""
        self.assertEqual(self.calc.divide(6, 2), 2) # Should be 3

if __name__ == '__main__':
    unittest.main()