# More details about frame: https://www.pythontutorial.net/tkinter/tkinter-frame/

# GUI Design: 
# Row 0 has three frames. 
# Frame 1 in Column 0, Frame 2 in Column 1, Frame 3 in Column 2
# -- Frame 1: 
# 	-- has labels and fields for Name and City. 
	# -- has two check boxes: Python and Java
# -- Frame 2:
# 	-- has three buttons
# -- Frame 3:
# 	-- has three buttons
# 
# Row 1 has one frame Frame 4. 
# -- Frame 4:
# 	-- has one label, one text field and one button



import tkinter as tk
from tkinter import RAISED, RIDGE, ttk, TclError, Text

class Frame1(ttk.Frame):
    def __init__(self, container):
        super().__init__(container)
        self.__create_frame_1()
    
    def __create_frame_1(self):    
        #frame1 = ttk.Frame(self)

        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=3)
    
        ttk.Label(self, text='Name:').grid(column=0, row=0, sticky=tk.W)
        name_entry = ttk.Entry(self, width=30)
        name_entry.focus()
        name_entry.grid(column=1, row=0, sticky=tk.W)
   
        ttk.Label(self, text='City:').grid(column=0, row=1, sticky=tk.W)
        city_entry = ttk.Entry(self, width=30)
        city_entry.grid(column=1, row=1, sticky=tk.W)
    
        pythonlanguage = tk.StringVar()
        pythonlanguage_check = ttk.Checkbutton(
            self,
            text='Python',
            variable=pythonlanguage,
            command=lambda: print(pythonlanguage.get()))
        pythonlanguage_check.grid(column=0, row=2, sticky=tk.W)

        javalanguage = tk.StringVar()
        javalanguage_check = ttk.Checkbutton(
            self,
            variable=javalanguage,
            text='Java',
            command=lambda: print(javalanguage.get()))
        javalanguage_check.grid(column=0, row=3, sticky=tk.W)

        for widget in self.winfo_children():
            widget.grid(padx=5, pady=5)

        return self

class Frame2(ttk.Frame):
    def __init__(self, container):
        super().__init__(container)
        self.__create_frame_2()
        
    def __create_frame_2(self):
        #frame2 = ttk.Frame(self, borderwidth=1, relief=RIDGE, padding=5)

        self.columnconfigure(0, weight=2)    

        ttk.Button(self, text='Save').grid(column=0, row=0)
        ttk.Button(self, text='Clear').grid(column=0, row=1)
        ttk.Button(self, text='Delete').grid(column=0, row=2)
        ttk.Button(self, text='Archive').grid(column=0, row=3)

        for widget in self.winfo_children():
            widget.grid(padx=5, pady=5)    

        return self

class Frame3(ttk.Frame):
    def __init__(self, container):
        super().__init__(container)
        self.__create_frame_3()
        
    def __create_frame_3(self):
        #frame3 = ttk.Frame(self)

        self.columnconfigure(0, weight=1)
    
        ttk.Button(self, text='Next').grid(column=0, row=0)
        ttk.Button(self, text='Previous').grid(column=0, row=1)
        ttk.Button(self, text='Close').grid(column=0, row=2)

        for widget in self.winfo_children():
            widget.grid(padx=5, pady=5)    

        return self

class Frame4(ttk.Frame):
    def __init__(self, container):
        super().__init__(container)
        self.__create_frame_4()
        
    def __create_frame_4(self):
        #frame4 = ttk.Frame(self, borderwidth=2, relief=RAISED, padding=5)

        self.columnconfigure(0, weight=7)

        ttk.Label(self, text='Comments:').grid(row=0, sticky=tk.W)
        tk.Text(self, height=6).grid(row=1)
        ttk.Button(self, text='Save Comments').grid(row=2, sticky=tk.W)

        for widget in self.winfo_children():
            widget.grid(padx=5, pady=5)    
    
        return self


class App(tk.Tk):
    def __init__(self):
        super().__init__()
        self.title('Favourite Language')
        self.geometry('600x350')
        self.resizable(1, 1)
        # windows only (remove the minimize/maximize button)
        # self.attributes('-toolwindow', True) 
        #try:
        #    self.attributes('-toolwindow', True)
        #except TclError:
        #    print(' - toolwindow Not supported on your platform')
        
        self.columnconfigure(0, weight=4)
        self.columnconfigure(1, weight=2)
        self.columnconfigure(2, weight=1)
               

        self.__create_main_window()


    def __create_main_window(self):
        
        frame_1 = Frame1(self)
        frame_1.grid(column=0, row=0)

        frame_2 = Frame2(self)
        frame_2.grid(column=1, row=0)

        frame_3 = Frame3(self)
        frame_3.grid(column=2, row=0)

        frame_4 = Frame4(self)
        frame_4.grid(row=1, columnspan=3)
        

if __name__ == "__main__":
    app = App()
    app.mainloop()







