from tkinter import *
import json
import os
from tkinter import messagebox

window = Tk()
window.title("Staff")

# Main window widgets
lstName = Listbox(window, width=15, height=10)
yscroll = Scrollbar(command=lstName.yview)
lstName.grid(row=0, column=0, columnspan=2, padx=5, pady=5)
yscroll.grid(row=0, column=2, sticky=NS)
lstName.config(yscrollcommand=yscroll.set)

txt = Text(window, width=30, height=10)
txt.grid(row=0, column=3, padx=5, pady=5)

current_dir = os.path.dirname(os.path.abspath(__file__))
json_path = os.path.join(current_dir, "users.json")

try:
    with open(json_path, 'r') as f:
        staff_list = json.load(f)
        for staff in staff_list:
            lstName.insert(END, staff[0])
except FileNotFoundError:
    staff_list = []
    messagebox.showwarning("Warning", "users.json not found. Starting with empty list.")

def show_add_window():
    add_window = Toplevel(window)
    add_window.title("Add New Staff")
    
    form_frame = Frame(add_window, padx=20, pady=10)
    form_frame.pack()
    
    name_var = StringVar()
    position_var = StringVar()
    room_var = StringVar()
    email_var = StringVar()
    
    Label(form_frame, text="Name:").grid(row=0, column=0, sticky=W, pady=5)
    name_entry = Entry(form_frame, textvariable=name_var)
    name_entry.grid(row=0, column=1, pady=5)
    
    Label(form_frame, text="Position:").grid(row=1, column=0, sticky=W, pady=5)
    position_entry = Entry(form_frame, textvariable=position_var)
    position_entry.grid(row=1, column=1, pady=5)
    
    Label(form_frame, text="Room:").grid(row=2, column=0, sticky=W, pady=5)
    room_entry = Entry(form_frame, textvariable=room_var)
    room_entry.grid(row=2, column=1, pady=5)
    
    Label(form_frame, text="Email:").grid(row=3, column=0, sticky=W, pady=5)
    email_entry = Entry(form_frame, textvariable=email_var)
    email_entry.grid(row=3, column=1, pady=5)
    
    def add_staff():
        name = name_var.get()
        position = position_var.get()
        room = room_var.get()
        email = email_var.get()
        
        if name and position and room and email:
            new_staff = [name, position, room, email]
            staff_list.append(new_staff)
            lstName.insert(END, name)
            add_window.destroy()
            messagebox.showinfo("Success", "Staff member added successfully!")
        else:
            messagebox.showerror("Error", "Please fill all fields!")
    
    Button(form_frame, text="Add Staff", command=add_staff).grid(row=4, column=0, columnspan=2, pady=10)

def remove_staff():
    if not lstName.curselection():
        messagebox.showerror("Error", "Please select a staff member to remove!")
        return
        
    if messagebox.askyesno("Confirm", "Are you sure you want to remove this staff member?"):
        idx = lstName.curselection()[0]
        del staff_list[idx]
        lstName.delete(idx)
        txt.delete(1.0, END)
        messagebox.showinfo("Success", "Staff member removed successfully!")

def save_to_file():
    try:
        with open(json_path, 'w') as f:
            json.dump(staff_list, f)
        messagebox.showinfo("Success", "Data saved successfully!")
    except Exception as e:
        messagebox.showerror("Error", f"Failed to save data: {str(e)}")

def show_details(evt):
    if not lstName.curselection():
        return
        
    idx = lstName.curselection()[0]
    staff = staff_list[idx]
    
    txt.delete(1.0, END)
    for info in staff:
        txt.insert(END, info + '\n')

button_frame = Frame(window)
button_frame.grid(row=1, column=3, pady=5)

Button(button_frame, text="Add", command=show_add_window).pack(side=LEFT, padx=5)
Button(button_frame, text="Remove", command=remove_staff).pack(side=LEFT, padx=5)
Button(button_frame, text="Save", command=save_to_file).pack(side=LEFT, padx=5)

# Bind selection event
lstName.bind('<<ListboxSelect>>', show_details)

window.mainloop()