import tkinter as tk
from tkinter import ttk
from tkinter.messagebox import showinfo, showerror
import json
import os

class UserAccount:
    def __init__(self, username, password, position="", room="", email=""):
        self.__username = username
        self.__password = password
        self.__position = position
        self.__room = room
        self.__email = email
    
    def get_username(self):
        return self.__username
    
    def get_password(self):
        return self.__password
        
    def to_dict(self):
        return {
            "username": self.__username,
            "password": self.__password,
            "position": self.__position,
            "room": self.__room,
            "email": self.__email
        }

class LoginApp(tk.Tk):
    def __init__(self):
        super().__init__()
        
        self.title('Login System')
        self.geometry('300x150')
        self.resizable(0, 0)
        
        # Configure grid
        self.columnconfigure(0, weight=1)
        self.columnconfigure(1, weight=3)
        
        # Load users from JSON
        self.load_users()
        
        # Create widgets
        self.create_widgets()
    
    def load_users(self):
        self.users = []
        current_dir = os.path.dirname(os.path.abspath(__file__))
        self.json_path = os.path.join(current_dir, "login.json")
        
        try:
            with open(self.json_path, 'r') as f:
                user_list = json.load(f)
                for user_data in user_list:
                    user = UserAccount(
                        user_data["username"],
                        user_data["password"],
                        user_data["position"],
                        user_data["room"],
                        user_data["email"]
                    )
                    self.users.append(user)
        except FileNotFoundError:
            showerror("Error", "login.json not found!")
            self.users = []
    
    def create_widgets(self):
        # Username
        username_label = ttk.Label(self, text="Username:")
        username_label.grid(column=0, row=0, padx=5, pady=5)
        
        self.username_var = tk.StringVar()
        username_entry = ttk.Entry(self, textvariable=self.username_var)
        username_entry.grid(column=1, row=0, sticky=tk.EW, padx=5, pady=5)
        username_entry.bind('<Return>', lambda e: self.password_entry.focus())
        
        # Password
        password_label = ttk.Label(self, text="Password:")
        password_label.grid(column=0, row=1, padx=5, pady=5)
        
        self.password_var = tk.StringVar()
        self.password_entry = ttk.Entry(self, textvariable=self.password_var, show="*")
        self.password_entry.grid(column=1, row=1, sticky=tk.EW, padx=5, pady=5)
        self.password_entry.bind('<Return>', lambda e: self.login())
        
        # Button Frame
        button_frame = ttk.Frame(self)
        button_frame.grid(column=0, row=3, columnspan=2, pady=10)
        
        # Login button
        login_button = ttk.Button(button_frame, text="Login", command=self.login)
        login_button.pack(side=tk.LEFT, padx=5)
        
        # Register button
        register_button = ttk.Button(button_frame, text="Register", command=self.show_register)
        register_button.pack(side=tk.LEFT, padx=5)
    
    def login(self):
        username = self.username_var.get()
        password = self.password_var.get()
        
        # Kiểm tra tài khoản tồn tại
        user_exists = any(user.get_username() == username for user in self.users)
        
        for user in self.users:
            if user.get_username() == username and user.get_password() == password:
                showinfo("Success", f"Welcome {username}!")
                return
        
        if not user_exists:
            showerror("Error", "Account not found!\nPlease register by clicking the Register button.")
        else:
            showerror("Error", "Invalid password!")
    
    def show_register(self):
        register_window = tk.Toplevel(self)
        register_window.title("Register New User")
        register_window.geometry("500x250")
        register_window.resizable(0, 0)

        # Configure the grid to center content
        for i in range(6):
            register_window.rowconfigure(i, weight=1)
        register_window.columnconfigure(0, weight=1)
        register_window.columnconfigure(1, weight=0)
        register_window.columnconfigure(2, weight=2)
        register_window.columnconfigure(3, weight=1)

        # Username
        ttk.Label(register_window, text="Username:").grid(row=0, column=0, padx=5, pady=5, sticky='e')
        username_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=username_var).grid(row=0, column=2, padx=5, pady=5, sticky="ew")

        # Password
        ttk.Label(register_window, text="Password:").grid(row=1, column=0, padx=5, pady=5, sticky='e')
        password_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=password_var, show="*").grid(row=1, column=2, padx=5, pady=5, sticky="ew")

        # Position
        ttk.Label(register_window, text="Position:").grid(row=2, column=0, padx=5, pady=5, sticky='e')
        position_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=position_var).grid(row=2, column=2, padx=5, pady=5, sticky="ew")

        # Room
        ttk.Label(register_window, text="Room:").grid(row=3, column=0, padx=5, pady=5, sticky='e')
        room_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=room_var).grid(row=3, column=2, padx=5, pady=5, sticky="ew")

        # Email
        ttk.Label(register_window, text="Email:").grid(row=4, column=0, padx=5, pady=5, sticky='e')
        email_var = tk.StringVar()
        ttk.Entry(register_window, textvariable=email_var).grid(row=4, column=2, padx=5, pady=5, sticky="ew")

        def register():
            username = username_var.get()
            password = password_var.get()
            position = position_var.get()
            room = room_var.get()
            email = email_var.get()

            if username and password and position and room and email:
                if any(user.get_username() == username for user in self.users):
                    showerror("Error", "Username already exists!")
                    return
                
                elif any(user.get_email() == email for user in self.users):
                    showerror("Error", "Email already exists!")
                    return
            
                # Add new user
                new_user = UserAccount(username, password, position, room, email)
                self.users.append(new_user)

                # Update JSON file
                user_list = [user.to_dict() for user in self.users]
                with open(self.json_path, 'w') as f:
                    json.dump(user_list, f, indent=4)

                showinfo("Success", "Registration successful!")
                register_window.destroy()
            else:
                showerror("Error", "Please fill all fields!")

        def cancel():
            register_window.destroy()

        # Button Frame
        button_frame = ttk.Frame(register_window)
        button_frame.grid(row=5, column=1, columnspan=2, pady=15, sticky="ew")
        
        # Centering buttons
        button_frame.columnconfigure(0, weight=1)
        button_frame.columnconfigure(1, weight=1)

        # OK button
        ttk.Button(button_frame, text="OK", command=register).grid(row=0, column=0, padx=10)
        
        # Cancel button
        ttk.Button(button_frame, text="Cancel", command=cancel).grid(row=0, column=1, padx=10)


if __name__ == "__main__":
    app = LoginApp()
    app.mainloop()